# Recipe.pm
# michael dungan - mpd@rochester.rr.com
# definition of a recipe object
#
package Rec::Recipe;
use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);

use Exporter;

my $RCSID =	'$Id: Recipe.pm,v 2.1 2002/04/12 01:48:01 vega Exp $';

$VERSION =	'0.60';
@ISA =		qw(Exporter);

@EXPORT_OK = qw(ingredients directions serves title);

#----------
# constructor
#----------
sub new {
	my $this = shift;
    my $classname  = ref($this) || $this;	
    my $self;
	$self = {
	    INGREDIENTS  => [],
	    DIRECTIONS   => [],
	    SERVES       => undef,
	    TITLE        => undef
	};
    bless($self, $classname);
    return $self;
}

#----------
# Accessors/Mutators
#----------
sub title {
    my $self = shift;
    if (@_) { $self->{TITLE} = shift; }
    return    $self->{TITLE};
}
   
sub serves {
    my $self = shift;
    if (@_) { $self->{SERVES} = shift; }
    return    $self->{SERVES};
}
   
sub ingredients {
    my $self = shift;
    if (@_) { @{ $self->{INGREDIENTS} } = @_; }
    return    @{ $self->{INGREDIENTS} };
}

sub directions {
    my $self = shift;
    if (@_) { @{ $self->{DIRECTIONS} } = @_; }
    return    @{ $self->{DIRECTIONS} };
}

1;

__END__

=head1 NAME

Rec::Recipe - Module for storage and manipulation of recipe data.

=head1 SYNOPSIS

use Rec::Recipe;

$recipe = Rec::Recipe->new();

$recipe->title('Recipe Title');

$recipe->serves(4);

$recipe->ingredients(qw(eggs fish cheese));

$recipe->directions('Mix ingredients in a bowl.', 'Eat quickly.');

=head1 DESCRIPTION

Recipe provides an abstract class to manipulate a recipe used for
cooking. The objects can then be used in a cookbook program.

=head2 Class Methods

=over 4

=item * title($new_title)

Optionally takes a string representing the new title for the
recipe in question.
If no title given, just returns the current title.

=item * serves($new_serves)

Optionally takes a string representing the new value of how
many people the recipe serves.
If no value given, just returns the current value.

=item * ingredients(@new_ingredients)

Optionally takes a list of strings, each representing an
ingredient. In the future, an ingredient module may be
written.
If no value given, just returns the current value.

=item * directions(@new_directions)

Optionally takes a list of strings, each representing a step
in the recipe.
If no value given, just returns the current value.

=back

=head1 AUTHOR

Michael Dungan <mpd@rochester.rr.com>

=cut
